Security Advisories (3)
CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2018-25032 (2022-03-25)

zlib before 1.2.12 allows memory corruption when deflating (i.e., when compressing) if the input has many distant matches.

CVE-2011-3045 (2012-03-22)

Integer signedness error in the png_inflate function in pngrutil.c in libpng before 1.4.10beta01, as used in Google Chrome before 17.0.963.83 and other products, allows remote attackers to cause a denial of service (application crash) or possibly execute arbitrary code via a crafted PNG file, a different vulnerability than CVE-2011-3026.

NAME

Tk - a graphical user interface toolkit for Perl

SYNOPSIS

use Tk;
$top = new MainWindow;
MainLoop;

DESCRIPTION

The Perl/Tk manual is split up into a number of sections:

Introduction

Tk Geometry Management

Binding Events and Callbacks

Tk Image Classes

Tk Widget Classes

Tix Extensions

Tk Generic Methods

User Interaction

Creating and Configuring Widgets

Popups and Dialogs

Derived Widgets

C Programming

  • Internals

  • pTk

  • 3DBorder

  • BackgdErr

  • BindTable

  • CanvPsY

  • CanvTkwin

  • CanvTxtInfo

  • Clipboard

  • ClrSelect

  • ConfigWidg

  • ConfigWind

  • CoordToWin

  • CrtErrHdlr

  • CrtGenHdlr

  • CrtImgType

  • CrtItemType

  • CrtMainWin

  • CrtPhImgFmt

  • CrtSelHdlr

  • CrtWindow

  • DeleteImg

  • DoOneEvent

  • DoWhenIdle

  • DrawFocHlt

  • EventHndlr

  • EventInit

  • FileHndlr

  • FindPhoto

  • FontId

  • FreeXId

  • GeomReq

  • GetAnchor

  • GetBitmap

  • GetCapStyl

  • GetClrmap

  • GetColor

  • GetCursor

  • GetFont

  • GetFontStr

  • GetGC

  • GetImage

  • GetJoinStl

  • GetJustify

  • GetOption

  • GetPixels

  • GetPixmap

  • GetRelief

  • GetRootCrd

  • GetScroll

  • GetSelect

  • GetUid

  • GetVisual

  • GetVRoot

  • HandleEvent

  • IdToWindow

  • ImgChanged

  • InternAtom

  • MainLoop

  • MaintGeom

  • MainWin

  • ManageGeom

  • MapWindow

  • MeasureChar

  • MoveToplev

  • Name

  • NameOfImg

  • OwnSelect

  • ParseArgv

  • Preserve

  • QWinEvent

  • Restack

  • RestrictEv

  • SetAppName

  • SetClass

  • SetGrid

  • SetVisual

  • Sleep

  • StrictMotif

  • TextLayout

  • TimerHndlr

  • Tk_Init

  • WindowId

Implementation

Experimental Modules

Other Modules and Languages

AUTHOR

Nick Ing-Simmons

SEE ALSO

perl, wish(1).

Alternative Perl modules implementing the Tk toolkit: Tkx, Tcl::Tk.